==> AsposeCellsCloud-CellsApi-24.2.1.tar.gz: AsposeCellsCloud-CellsApi-24.2.1/lib/AsposeCellsCloud/Object/PivotTableOperateParameter.pm <==
=begin comment

Copyright (c) 2024 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::PivotTableOperateParameter;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::OperateParameter; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'PivotTableOperateParameter',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'source_data' => {
     	datatype => 'string',
     	base_name => 'SourceData',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'dest_cell_name' => {
     	datatype => 'string',
     	base_name => 'DestCellName',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'table_name' => {
     	datatype => 'string',
     	base_name => 'TableName',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'use_same_source' => {
     	datatype => 'boolean',
     	base_name => 'UseSameSource',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'pivot_table_index' => {
     	datatype => 'int',
     	base_name => 'PivotTableIndex',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'pivot_field_rows' => {
     	datatype => 'ARRAY[int?]',
     	base_name => 'PivotFieldRows',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'pivot_field_columns' => {
     	datatype => 'ARRAY[int?]',
     	base_name => 'PivotFieldColumns',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'pivot_field_data' => {
     	datatype => 'ARRAY[int?]',
     	base_name => 'PivotFieldData',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'operate_type' => {
     	datatype => 'string',
     	base_name => 'OperateType',
     	description => '',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'source_data' => 'string',
    'dest_cell_name' => 'string',
    'table_name' => 'string',
    'use_same_source' => 'boolean',
    'pivot_table_index' => 'int',
    'pivot_field_rows' => 'ARRAY[int?]',
    'pivot_field_columns' => 'ARRAY[int?]',
    'pivot_field_data' => 'ARRAY[int?]',
    'operate_type' => 'string' 
} );

__PACKAGE__->attribute_map( {
    'source_data' => 'SourceData',
    'dest_cell_name' => 'DestCellName',
    'table_name' => 'TableName',
    'use_same_source' => 'UseSameSource',
    'pivot_table_index' => 'PivotTableIndex',
    'pivot_field_rows' => 'PivotFieldRows',
    'pivot_field_columns' => 'PivotFieldColumns',
    'pivot_field_data' => 'PivotFieldData',
    'operate_type' => 'OperateType' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;

==> AsposeCellsCloud-CellsApi-24.5.tar.gz: AsposeCellsCloud-CellsApi-24.5/lib/AsposeCellsCloud/Object/PivotTableOperateParameter.pm <==
=begin comment

Copyright (c) 2024 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::PivotTableOperateParameter;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::OperateParameter; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => 'Represents pivot table operate parameter.',
                                  class => 'PivotTableOperateParameter',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'source_data' => {
     	datatype => 'string',
     	base_name => 'SourceData',
     	description => 'Represents source data of pivot table.',
     	format => '',
     	read_only => '',
     		},
     'dest_cell_name' => {
     	datatype => 'string',
     	base_name => 'DestCellName',
     	description => 'Represents start cell name of the pivot table.',
     	format => '',
     	read_only => '',
     		},
     'table_name' => {
     	datatype => 'string',
     	base_name => 'TableName',
     	description => 'Represents table name of pivot table.',
     	format => '',
     	read_only => '',
     		},
     'use_same_source' => {
     	datatype => 'boolean',
     	base_name => 'UseSameSource',
     	description => 'Represents whether the same source is used.',
     	format => '',
     	read_only => '',
     		},
     'pivot_table_index' => {
     	datatype => 'int',
     	base_name => 'PivotTableIndex',
     	description => 'Represents pivot table index.',
     	format => '',
     	read_only => '',
     		},
     'pivot_field_rows' => {
     	datatype => 'ARRAY[int?]',
     	base_name => 'PivotFieldRows',
     	description => 'Represents pivot row fields.',
     	format => '',
     	read_only => '',
     		},
     'pivot_field_columns' => {
     	datatype => 'ARRAY[int?]',
     	base_name => 'PivotFieldColumns',
     	description => 'Represents pivot column fields.',
     	format => '',
     	read_only => '',
     		},
     'pivot_field_data' => {
     	datatype => 'ARRAY[int?]',
     	base_name => 'PivotFieldData',
     	description => 'Represents pivot data field.',
     	format => '',
     	read_only => '',
     		},
     'operate_type' => {
     	datatype => 'string',
     	base_name => 'OperateType',
     	description => '',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'source_data' => 'string',
    'dest_cell_name' => 'string',
    'table_name' => 'string',
    'use_same_source' => 'boolean',
    'pivot_table_index' => 'int',
    'pivot_field_rows' => 'ARRAY[int?]',
    'pivot_field_columns' => 'ARRAY[int?]',
    'pivot_field_data' => 'ARRAY[int?]',
    'operate_type' => 'string' 
} );

__PACKAGE__->attribute_map( {
    'source_data' => 'SourceData',
    'dest_cell_name' => 'DestCellName',
    'table_name' => 'TableName',
    'use_same_source' => 'UseSameSource',
    'pivot_table_index' => 'PivotTableIndex',
    'pivot_field_rows' => 'PivotFieldRows',
    'pivot_field_columns' => 'PivotFieldColumns',
    'pivot_field_data' => 'PivotFieldData',
    'operate_type' => 'OperateType' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;
